Stan Math Library: stan/math/fwd/scal/fun/value_of_rec.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

value_of_rec.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_VALUE_OF_REC_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_VALUE_OF_REC_HPP
3
4 #include <stan/math/prim/scal/fun/value_of_rec.hpp>
5 #include <stan/math/fwd/core.hpp>
6
7 namespace stan {
8 namespace math {
9
20 template <typename T>
21 inline double value_of_rec(const fvar<T>& v) {
22 using stan::math::value_of_rec;
23 return value_of_rec(v.val_);
24 }
25
26
27 }
28 }
29 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::value_of_rec
double value_of_rec(const fvar< T > &v)
Return the value of the specified variable.
Definition: value_of_rec.hpp:21
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
value_of_rec.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.